@@ -1,4 +1,4 @@
-from django.conf.urls import url
+from django.urls import path, re_path
 
 from .. import views
 
@@ -7,16 +7,16 @@ app_name = "creators"
 
 urlpatterns = [
     # Individuals:
-    url(regex=r"^$", view=views.CreatorListView.as_view(), name="creator_list"),
+    path("", view=views.CreatorListView.as_view(), name="creator_list"),
     #  Groups:
-    url(
-        regex=r"^groups/$",
+    path(
+        "groups/",
         view=views.CreatorListView.as_view(),
         name="creator_list_group",
         kwargs={"kind": "group"},
     ),
-    url(
-        regex=r"^(?P<slug>[\w-]+)/$",
+    re_path(
+        r"^(?P<slug>[\w-]+)/$",
         view=views.CreatorDetailView.as_view(),
         name="creator_detail",
     ),
